@@ -36,7 +36,8 @@ class Regbot:
   @classmethod
   def buySignalGenerator(cls,opening,closing):
     scalledInput = cls.prepareInput(opening,closing)
-    return (cls.loadmodel().predict(scalledInput) > 0.0).astype(int)[0]
+    return (cls.loadmodel().predict_proba(scalledInput)[:,1] > 0.0).astype(int)[0]
+    #return (cls.loadmodel().predict(scalledInput) > 0).astype(int)[0]
     
 
 
